/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 6: 	Relationship between aging and exports
			of industrial robots
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_robot_exports_aging.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


***Program that defines the plot-style ***
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string) name(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	reg `y_vars' `x_var' `controls'  `wt'  `if', r
	local beta: di %3.2f  _b[`x_var']
	local tstat: di %3.2f _b[`x_var']/_se[`x_var']
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: replace `tag_label'=1 if country_name=="united states"
	quietly: replace `tag_label'=1 if country_name=="finland"
	
	tempvar labvar
	gen `labvar'=upper(country_name)
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=.,  color(dkorange) msize(*1)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mlabel(`labvar')  mlabcolor(navy) mlabpos(7) msize(*0)), ///
		   ylabel(#8, noticks angle(horizontal)) legend(off) xtitle("`xtitle'", size(large)) ytitle("") title("`ytitle'", position(11)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(4) xsize(7) name("`name'", replace)
   
end

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1996_2015.dta", assert(1 3) nogenerate
merge 1:1 isocode using "${project}/clean_data/comtrade_robots_1996_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*compute total imports of intermediate goods*
foreach flow in im_ ex_ re_{
egen intermediate_`flow'96=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}
 
*sample selection: drop Nigeria---a large outlier*
drop if country_name=="nigeria" 

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1995)

*regions*
encode new_region, gen(dreg)

*outcome: share divided by total intermediate imports going back to 1996, the year that robot imports became available*
drop if tv_ex_robots_orig<0
gen share_robots=ln(tv_ex_robots_orig/intermediate_ex_96)
gen ln_exports=ln(intermediate_ex_96)

*define sample*
quietly: reg share_robots  change_dependency  $country_covariates_1995  i.dreg  $imports_weights, r
gen full_sample=e(sample)

* names in figures *
replace country_name="hong kong" if country_name=="china,hong kong s.a.r."
replace country_name="china" if country_name=="china p.rep."


**********************************************
*********Left Panel of Figure 6***************
**********************************************
resid_plot share_robots change_dependency if full_sample==1 $exports_weights, ///
           control( i.dreg $country_covariates) ///
		   xtitle("Aging between 1990 and 2025") ytitle(`"Share of robots in intermediate exports" "(in logs) between 1996 and 2015---all countries"') ///
		   name("full_sample")

**********************************************
********Right Panel of Figure 6***************
**********************************************		   
resid_plot share_robots change_dependency if new_region=="OECD" $exports_weights, ///
           control($country_covariates) ///
		   xtitle("Aging between 1990 and 2025") ytitle(`"Share of robots in intermediate exports" "(in logs) between 1996 and 2015---OECD"') ///
		   name("oecd_sample")		   
		   
gr combine full_sample oecd_sample, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) xsize(8) cols(2) 
graph export "$project/results/figure_robot_exports_aging.pdf", as(pdf) replace
