/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 9: 	Relationship between aging and different
			types of patents
			
Notes: 		1. Some of the regressions generate warnings.
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/patents_categories.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
	
	**************************
	*******Housekeeping*******
	**************************

* create dataset to save estimation results *
tempfile estimates_save
clear
set obs 20
gen category=""
gen ols_full_b=.
gen ols_full_se=.
gen ols_oecd_b=.
gen ols_oecd_se=.
gen iv_full_b=.
gen iv_full_se=.
gen iv_oecd_b=.
gen iv_oecd_se=.
save `estimates_save', replace


* covariates *
use "$project/clean_data/country_covariates.dta", clear

* patent data---drop others category *
merge 1:1 isocode using "${project}/clean_data/country_patents.dta", keep(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg)

*dependent variable*
gen ln_patents=ln(t_utility_patents)

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

	************************
	*******Estimation*******
	************************   

* Loop over different types of patents *
local i=1
foreach cat in  subpanelA automation_rel automation_901 automation_crossref25 automation_crossref10 words_robot words_ind_robot words_robot_manipulator words_numcontrol subpanelB class_comp words_computer class_soft words_software class_nano words_nano class_pharm words_pharma   {

if "`cat'"=="subpanelA" | "`cat'"=="subpanelB" | "`cat'"=="subpanelC" {
preserve
use `estimates_save', clear
replace category="ph" in `i'
local i=`i'+1
replace category="`cat'" in `i'
save `estimates_save', replace
restore
}
else{   
*dep var
gen share_`cat'=ln(`cat')

reg share_`cat' change_dependency  $country_covariates_1990 i.dreg $patent_weights, r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_save', clear
replace category="`cat'" in `i'
replace ols_full_b=`beta' in `i'
replace ols_full_se=`serr' in `i'
save `estimates_save', replace
restore

reg share_`cat' change_dependency  $country_covariates_1990 i.dreg $patent_weights if new_region=="OECD", r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_save', clear
replace ols_oecd_b=`beta' in `i'
replace ols_oecd_se=`serr' in `i'
save `estimates_save', replace
restore

ivreg2 share_`cat' (change_dependency=$instruments)  $country_covariates_1990 i.dreg $patent_weights, r partial(i.dreg)
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_save', clear
replace iv_full_b=`beta' in `i'
replace iv_full_se=`serr' in `i'
save `estimates_save', replace
restore

ivreg2 share_`cat' (change_dependency=$instruments)  $country_covariates_1990 i.dreg $patent_weights if new_region=="OECD", r partial(i.dreg)
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_save', clear
replace iv_oecd_b=`beta' in `i'
replace iv_oecd_se=`serr' in `i'
save `estimates_save', replace
restore
}

local i=`i'+1
}


use `estimates_save', clear
drop if cat==""
gen base_num=_n
expand 3
sort base_num
gen number=60-_n

*label panels*
replace category="..." if category=="ph"
replace category="Group 1: related to industrial automation" if category=="subpanelA" 
replace category="Group 2: Panel--other technology classes" if category=="subpanelB"

*label categories* words_sensor words_comp words_soft words_nano words_pharma  
replace category="Classes related to 901" if category=="automation_rel"
replace category="Classes referencing 901 (25% threshold)" if category=="automation_crossref25" 
replace category="Classes referencing 901 (10% threshold)" if category=="automation_crossref10" 
replace category="901 USPTO class" if category=="automation_901" 
replace category="Words related to robots" if category=="words_robot"  
replace category="Words related to industrial robots" if category=="words_ind_robot"   
replace category="Words related to robots and manipulators" if category=="words_robot_manipulator" /**/ 
replace category="Words related to numerical control" if category=="words_numcontrol"  
replace category="Classes related to computers" if category=="class_comp"  
replace category="Words related to computers" if category=="words_computer"  
replace category="Classes related to software" if category=="class_soft"
replace category="Words related to software" if category=="words_software"
replace category="Classes related to nanotechnology" if category=="class_nano"  
replace category="Words related to nanotechnology" if category=="words_nano"
replace category="Classes related to pharmaceuticals" if category=="class_pharm"  
replace category="Words related to pharmaceuticals" if category=="words_pharma"


replace category=" " if number==3*floor(number/3)+1
replace category=" " if number==3*floor(number/3)

gen full_sample=1 if  number==3*floor(number/3)+2
gen oecd_sample=1 if  number==3*floor(number/3)+1

drop if number>56

labmask number, values(category)

gen iv_full_low=iv_full_b-1.65*iv_full_se
gen iv_full_high=iv_full_b+1.65*iv_full_se

gen iv_oecd_low=iv_oecd_b-1.65*iv_oecd_se
gen iv_oecd_high=iv_oecd_b+1.65*iv_oecd_se

twoway 	(bar iv_full_b number if full_sample==1, sort fcolor(white) fintensity(20) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    iv_full_low iv_full_high number if full_sample==1, sort lcolor(black) lwidth(vthin) horizontal msize(vsmall)) ///
		(scatter number iv_full_b if full_sample==1, mcolor(black) lcolor(black) msize(*.15)) ///
		(bar iv_oecd_b number if oecd_sample==1, sort fcolor(dkorange) fintensity(80) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap iv_oecd_low iv_oecd_high number if oecd_sample==1, sort lcolor(black) lwidth(vthin) horizontal msize(vsmall)) ///
		(scatter number iv_oecd_b if oecd_sample==1, mcolor(black) lcolor(black) msize(*.15)), ///
		ytitle("") yscale(noline) /// 
		ylabel(2(3)56, labels labsize(small) angle(horizontal) valuelabel noticks grid glpattern(solid) glcolor(gs12) glwidth(vvthin) nogextend) ///
		 xtitle("") xlabel(-3(1)3, labels valuelabel)  /// 
		legend(symysize(*.3) symxsize(*.6) order(1 "Full sample" 4 "OECD sample") region(lcolor(none)) bmargin(zero) size(small) pos(5) ) ///
		graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin)) xline(0, lcolor(black) lwidth(vthin))

graph export "$project/results/patents_categories.pdf", as(pdf)  replace




