/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 3: 	Stacked-differences estimates of the impact of
			aging on the adoption of industrial robots
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_stacked_ols.tex
			/results/table_stacked_iv.tex
			/results/table_stacked_ols_weighted.tex
			/results/table_stacked_iv_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* regions *
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* create stacked differences *
expand 2
encode country_name, gen(ccode)
gen period=""
bys country_name: replace period="1993_2005" if _n==1
bys country_name: replace period="2005_2015" if _n==2
encode period, gen(decade)
bys country_name: gen nperiod=_n
xtset ccode nperiod, delta(1)

*robot variables*
gen base1993_stock_pc=stock_robots_1993/$normalization_robots

* annualized change in robots for each subperiod *
gen change_robots=.
replace change_robots=(stock_robots_2005-stock_robots_1993)/(2005-1993)/$normalization_robots if period=="1993_2005"
replace change_robots=(stock_robots_2014-stock_robots_2005)/(2014-2005)/$normalization_robots if period=="2005_2015"

* aging variables in 25-year equivalents so that results are comparable to long differences *
gen change_dependency=.
replace change_dependency=(${aging_measure}2015-${aging_measure}2005)*25/10 if period=="2005_2015"
replace change_dependency=(${aging_measure}2005-${aging_measure}1990)*25/15 if period=="1993_2005"

* sample selection: countries with robot data and full covariates, excluding Japan and Russia *
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates  i.dreg
gen full_sample=e(sample)

* instruments interacted with period dummies *
foreach var of varlist $instruments{
gen idec1_`var'=(period=="1993_2005")*`var'
gen idec2_`var'=(period=="2005_2015")*`var'
}

	************************
	*******Estimation*******
	************************   

*****************************************************************************************
************************Table 3, Panel A: OLS models, unweighted ************************
*****************************************************************************************
reg change_robots 	change_dependency i.dreg i.decade if full_sample==1 , r cluster(ccode)
estimates store e1

reg change_robots 	change_dependency i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc if full_sample==1 , r cluster(ccode)
estimates store e2

xtreg change_robots change_dependency  i.decade if full_sample==1  , fe cluster(ccode) 
estimates store e3

reg change_robots 	change_dependency i.decade if new_region=="OECD"  , r cluster(ccode)
estimates store e4

reg change_robots 	change_dependency i.decade $country_covariates ln_manuf_va  base1993_stock_pc if new_region=="OECD"  , r cluster(ccode)
estimates store e5

xtreg change_robots change_dependency i.decade if new_region=="OECD"  , fe cluster(ccode) 
estimates store e6

* export tables *
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_stacked_ols.tex", style(tex) ///
varlabels(change_dependency     "Contemporaneous aging" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

*******************************************************************************************
************************Table 3, Panel B: IV estimates, unweighted ************************
*******************************************************************************************
ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.dreg i.decade if full_sample==1  , r cluster(ccode)  ffirst   partial(i.dreg i.decade)
estimates store e1

ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc if full_sample==1  , r cluster(ccode)  ffirst partial(i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc)
estimates store e2

xi: xtivreg2 change_robots  (change_dependency=idec1* idec2* )  i.decade if full_sample==1  , fe cluster(ccode)  ffirst
estimates store e3

ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.decade if new_region=="OECD"  , r cluster(ccode)  ffirst   partial(i.decade)
estimates store e4

ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.decade $country_covariates ln_manuf_va  base1993_stock_pc if new_region=="OECD"  , r cluster(ccode)  ffirst partial(i.decade $country_covariates ln_manuf_va  base1993_stock_pc)
estimates store e5

xi: xtivreg2 change_robots  (change_dependency=idec1* idec2* ) i.decade if new_region=="OECD"  , fe cluster(ccode) ffirst
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_stacked_iv.tex", style(tex) ///
varlabels(change_dependency     "Contemporaneous aging"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

gen change_birthrate_60_8090s=change_birthrate_60_80*(decade==1)
gen change_birthrate_60_8000s=change_birthrate_60_80*(decade==2) 

ivreg2 change_robots 		(change_dependency=change_birthrate_60_8090s change_birthrate_60_8000s) i.dreg i.decade if full_sample==1  , r cluster(ccode)  partial(i.dreg i.decade)

ivreg2 change_robots 		(change_dependency=change_birthrate_60_8090s change_birthrate_60_8000s) i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc if full_sample==1  , r cluster(ccode)  partial(i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc)

xi: xtivreg2 change_robots  (change_dependency=change_birthrate_60_8090s change_birthrate_60_8000s)  i.decade if full_sample==1  , fe cluster(ccode) 

ivreg2 change_robots 		(change_dependency=change_birthrate_60_8090s change_birthrate_60_8000s) i.decade if new_region=="OECD"  , r cluster(ccode)  partial(i.decade)

ivreg2 change_robots 		(change_dependency=change_birthrate_60_8090s change_birthrate_60_8000s) i.decade $country_covariates ln_manuf_va  base1993_stock_pc if new_region=="OECD"  , r cluster(ccode) partial(i.decade $country_covariates ln_manuf_va  base1993_stock_pc)

xi: xtivreg2 change_robots  (change_dependency=change_birthrate_60_8090s change_birthrate_60_8000s) i.decade if new_region=="OECD"  , fe cluster(ccode) 


gen single_stacked=0
replace single_stacked=ln(birthrate1950_1955)-ln(birthrate1965_1970) if decade==1
replace single_stacked=ln(birthrate1960_1965)-ln(birthrate1980_1985) if decade==1


ivreg2 change_robots 		(change_dependency=single_stacked) i.dreg i.decade if full_sample==1  , r cluster(ccode)  partial(i.dreg i.decade)

ivreg2 change_robots 		(change_dependency=single_stacked) i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc if full_sample==1  , r cluster(ccode)  partial(i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc)

xi: xtivreg2 change_robots  (change_dependency=single_stacked)  i.decade if full_sample==1  , fe cluster(ccode) 

ivreg2 change_robots 		(change_dependency=single_stacked) i.decade if new_region=="OECD"  , r cluster(ccode)  partial(i.decade)

ivreg2 change_robots 		(change_dependency=single_stacked) i.decade $country_covariates ln_manuf_va  base1993_stock_pc if new_region=="OECD"  , r cluster(ccode) partial(i.decade $country_covariates ln_manuf_va  base1993_stock_pc)

xi: xtivreg2 change_robots  (change_dependency=single_stacked) i.decade if new_region=="OECD"  , fe cluster(ccode) 



*****************************************************************************************
************************Table 3, Panel C: OLS models,   weighted ************************
*****************************************************************************************
reg change_robots 	change_dependency i.dreg i.decade if full_sample==1 $robot_weight, r cluster(ccode)
estimates store e1

reg change_robots 	change_dependency i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc if full_sample==1 $robot_weight, r cluster(ccode)
estimates store e2

xtreg change_robots change_dependency  i.decade if full_sample==1  $robot_weight, fe cluster(ccode) 
estimates store e3

reg change_robots 	change_dependency i.decade if new_region=="OECD"  $robot_weight, r cluster(ccode)
estimates store e4

reg change_robots 	change_dependency i.decade $country_covariates ln_manuf_va  base1993_stock_pc if new_region=="OECD"  $robot_weight, r cluster(ccode)
estimates store e5

xtreg change_robots change_dependency i.decade if new_region=="OECD"  $robot_weight, fe r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_stacked_ols_weighted.tex", style(tex) ///
varlabels(change_dependency     "Contemporaneous aging" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

*****************************************************************************************
************************Table 3, Panel D: IV models,    weighted ************************
*****************************************************************************************
ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.dreg i.decade if full_sample==1  $robot_weight, r cluster(ccode)  ffirst  partial(i.dreg i.decade)
estimates store e1

ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc if full_sample==1  $robot_weight, r cluster(ccode)  ffirst partial(i.dreg i.decade $country_covariates ln_manuf_va  base1993_stock_pc)
estimates store e2

xi: xtivreg2 change_robots  (change_dependency=idec1* idec2* )  i.decade if full_sample==1  $robot_weight, fe cluster(ccode)  ffirst
estimates store e3

ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.decade if new_region=="OECD"  $robot_weight, r cluster(ccode)  ffirst  partial(i.decade)
estimates store e4

ivreg2 change_robots 		(change_dependency=idec1* idec2* ) i.decade $country_covariates ln_manuf_va  base1993_stock_pc if new_region=="OECD"  $robot_weight, r cluster(ccode)  ffirst  partial(i.decade $country_covariates ln_manuf_va  base1993_stock_pc)
estimates store e5

xi: xtivreg2 change_robots  (change_dependency=idec1* idec2* ) i.decade if new_region=="OECD"  $robot_weight, fe cluster(ccode) ffirst
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_stacked_iv_weighted.tex", style(tex) ///
varlabels(change_dependency     "Contemporaneous aging" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )
