/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A11: 	Placebo estimates of the impact of past aging
			on the adoption of industrial robots
			
Notes: 		1. The placebo tests remove baseline aging from 
			the covariates, since this would affect interpretation
			of past aging coefficient

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_timing_past.tex
			/results/table_timing_past_weighted.tex
			/results/table_timing_horserace.tex
			/results/table_timing_horserace_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
gen past_dependency=(${aging_measure}1990-${aging_measure}1950)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
***************Table A11, Panel B: OLS models, past aging alone (unweighted) ************
*****************************************************************************************

reg change_robots 	past_dependency i.dreg if full_sample, r
estimates store e1

reg change_robots 	past_dependency $country_covariates_past i.dreg if full_sample, r
estimates store e2

reg change_robots 	past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if full_sample, r
estimates store e3

reg change_robots 	past_dependency i.dreg if new_region=="OECD", r
estimates store e4

reg change_robots 	past_dependency $country_covariates_past i.dreg if new_region=="OECD", r
estimates store e5

reg change_robots 	past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_timing_past.tex", style(tex) ///
varlabels(past_dependency     "Aging between 1950 and 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(past_dependency) ///
order(past_dependency)

*****************************************************************************************	
***************Table A11, Panel D: OLS models, past aging alone (weighted) **************
*****************************************************************************************

reg change_robots 	past_dependency i.dreg if full_sample $robot_weight, r
estimates store e1

reg change_robots 	past_dependency $country_covariates_past i.dreg if full_sample $robot_weight, r
estimates store e2

reg change_robots 	past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if full_sample $robot_weight, r
estimates store e3

reg change_robots 	past_dependency i.dreg if new_region=="OECD" $robot_weight, r
estimates store e4

reg change_robots 	past_dependency $country_covariates_past i.dreg if new_region=="OECD" $robot_weight, r
estimates store e5

reg change_robots 	past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if new_region=="OECD" $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_timing_past_weighted.tex", style(tex) ///
varlabels(past_dependency     "Aging between 1950 and 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(past_dependency) ///
order(past_dependency)

*****************************************************************************************	
***************Table A11, Panel A: OLS models, horse race (unweighted) ******************
*****************************************************************************************

reg change_robots 	change_dependency past_dependency i.dreg if full_sample, r
estimates store e1

reg change_robots 	change_dependency past_dependency $country_covariates_past i.dreg if full_sample, r
estimates store e2

reg change_robots 	change_dependency past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if full_sample, r
estimates store e3

reg change_robots 	change_dependency past_dependency i.dreg if new_region=="OECD", r
estimates store e4

reg change_robots 	change_dependency past_dependency $country_covariates_past i.dreg if new_region=="OECD", r
estimates store e5

reg change_robots 	change_dependency past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_timing_horserace.tex", style(tex) ///
varlabels(change_dependency   "Aging between 1990 and 2025"    ///
          past_dependency     "Aging between 1950 and 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency past_dependency) ///
order(change_dependency past_dependency)

*****************************************************************************************	
***************Table A11, Panel C: OLS models, horse race (weighted) ********************
*****************************************************************************************

reg change_robots 	change_dependency past_dependency i.dreg if full_sample $robot_weight, r
estimates store e1

reg change_robots 	change_dependency past_dependency $country_covariates_past i.dreg if full_sample $robot_weight, r
estimates store e2

reg change_robots 	change_dependency past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if full_sample $robot_weight, r
estimates store e3

reg change_robots 	change_dependency past_dependency i.dreg if new_region=="OECD" $robot_weight, r
estimates store e4

reg change_robots 	change_dependency past_dependency $country_covariates_past i.dreg if new_region=="OECD" $robot_weight, r
estimates store e5

reg change_robots 	change_dependency past_dependency ln_manuf_va  base1993_stock_pc $country_covariates_past i.dreg if new_region=="OECD" $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_timing_horserace_weighted.tex", style(tex) ///
varlabels(change_dependency   "Aging between 1990 and 2025"    ///
          past_dependency     "Aging between 1950 and 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency past_dependency) ///
order(change_dependency past_dependency)


