/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A6: 	Estimates of the impact of aging on the adoption of
			industrial robots controlling for institutional
			differences

Notes: 		1. Expanded to include employment protections
			and differences on labor taxation (only for OECD)

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_institutions_ols.tex			
			/results/table_institutions_iv.tex
			/results/table_institutions_single_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
	* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

*Unions: combine Rama dataset and ICTWSS*
gen union_density=rama_unions_85

replace union_density=ictwss_unions_90s if union_density==.
replace union_density=union_density/100

*Employment protection (normalized to 0--1)*
sum oecd_epl_v2
gen emp_protection=(oecd_epl_v2-r(min))/(r(max)-r(min))

*Tax wedge*
gen tax_wedge=oecd_taxwedge_00_SINGLE1/100

	************************
	*******Estimation*******
	************************

*****************************************************************************************	
************************Table A6, Panel A: OLS models, unweighted ***********************
*****************************************************************************************
* Full sample of countries *
reg change_robots 	change_dependency union_density  i.dreg $country_covariates if full_sample, r
estimates store e1

reg change_robots 	change_dependency emp_protection  i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_robots 	change_dependency union_density emp_protection i.dreg $country_covariates if full_sample, r
estimates store e3

* OECD sample *
reg change_robots 	change_dependency union_density  i.dreg $country_covariates if new_region=="OECD", r
estimates store e4

reg change_robots 	change_dependency emp_protection  i.dreg $country_covariates if new_region=="OECD", r
estimates store e5

reg change_robots 	change_dependency tax_wedge  i.dreg $country_covariates if new_region=="OECD", r
estimates store e6

reg change_robots 	change_dependency union_density emp_protection tax_wedge i.dreg $country_covariates if new_region=="OECD", r
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using  "$project/results/table_institutions_ols.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  emp_protection              "Employment protections" ///
		  tax_wedge           "OECD Labor tax wedge" ///
		  union_density "Union density") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency union_density emp_protection tax_wedge) ///
order(change_dependency union_density emp_protection tax_wedge) 

*****************************************************************************************	
************************Table A6, Panel B: IV models, unweighted ************************
*****************************************************************************************

* Full sample of countries *
ivreg2 change_robots 	(change_dependency=$instruments ) union_density  i.dreg $country_covariates if full_sample, r partial(i.dreg $country_covariates) ffirst
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) emp_protection  i.dreg $country_covariates if full_sample, r partial(i.dreg $country_covariates)  ffirst
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) union_density emp_protection i.dreg $country_covariates if full_sample, r partial(i.dreg $country_covariates) ffirst 
estimates store e3

* OECD sample *
ivreg2 change_robots 	(change_dependency=$instruments ) union_density  i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates)  ffirst
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) emp_protection  i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates)  ffirst
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) tax_wedge  i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates)  ffirst
estimates store e6

ivreg2 change_robots 	(change_dependency=$instruments ) union_density emp_protection tax_wedge i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates)  ffirst
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using   "$project/results/table_institutions_iv.tex", style(tex) ///
varlabels(change_dependency     	"Aging between 1990 and 2025" ///
		  emp_protection            "Employment protections" ///
		  tax_wedge                 "OECD Labor tax wedge" ///
		  union_density 			"Union density" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency union_density emp_protection tax_wedge) ///
order(change_dependency union_density emp_protection tax_wedge) 

*****************************************************************************************	
******************Table A6, Panel C: single IV models, unweighted ***********************
*****************************************************************************************

* Full sample of countries *
ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) union_density  i.dreg $country_covariates if full_sample, r partial(i.dreg $country_covariates) 
estimates store e1

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) emp_protection  i.dreg $country_covariates if full_sample, r partial(i.dreg $country_covariates) 
estimates store e2

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) union_density emp_protection i.dreg $country_covariates if full_sample, r partial(i.dreg $country_covariates) 
estimates store e3

* OECD sample *
ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) union_density  i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates) 
estimates store e4

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) emp_protection  i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates) 
estimates store e5

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) tax_wedge  i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates) 
estimates store e6

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) union_density emp_protection tax_wedge i.dreg $country_covariates if new_region=="OECD", r partial(i.dreg $country_covariates) 
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using  "$project/results/table_institutions_single_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  emp_protection        "Employment protections" ///
		  tax_wedge           	"OECD Labor tax wedge" ///
		  union_density "Union density") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f  ) labels("Observations" "First-stage $ F$  stat."  )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency union_density emp_protection tax_wedge) ///
order(change_dependency union_density emp_protection tax_wedge) 

